@@ -73,8 +73,7 @@ class Imports(object):
                 Formatting data table object ready for LAFF.
         """
 
-        import_table = Table.read(filepath, format='ascii.qdp', table_id=i)
-
+        import_table = Table.read(filepath, format='ascii.qdp', table_id=0)
         data = vstack(import_table).to_pandas()
         data = data.sort_values(by=['col1'])
         data = data.reset_index(drop=True)
@@ -83,6 +82,8 @@ class Imports(object):
             'col2': 'flux', 'col2_perr': 'flux_perr', 'col2_nerr': 'flux_nerr'})
         data['flare'] = False
 
+        data = None if len(data) <= 3 else data # Seems to break if data <= 3.
+
         return data
 
     def other():
